/* pgp4pine globals.c - global variables
 *
 * See common.c for the version and license.
 * Copyright (C) 1998 by Chris Wiegand
 */

#include "defines.h"
#include "structs.h"
#include <stdio.h>

/* ------------------------------------------------------------ */

FILE *debugFile;
int saveDebugFile;
char debugLine[DEBUG_LINE_LENGTH];

int prefsOverrideRecipients;
int prefsVerboseOutput;
int prefsAddComment;
int prefsExtraCRLFAtEnd;
int prefsCacheDecrypted;
int prefsCacheKeyrings;
int addDashR;
char prefsMyPager[MAX_COMMAND_LINE_LENGTH];
char DecryptCacheName[MAX_COMMAND_LINE_LENGTH];

#ifdef USE_DISPLAY_NAME
	char mySecretKey[EMAIL_ADDRESS_MAX_LENGTH];
#else
	char mySecretKey[KEY_ID_LENGTH];
#endif

struct myProfile *myUserPrefs;
struct pkiKey *publicKeyring;
struct pkiKey *secretKeyring;


